#[repr(u32)]pub enum MavDataStream {
MAV_DATA_STREAM_ALL = 0,
MAV_DATA_STREAM_RAW_SENSORS = 1,
MAV_DATA_STREAM_EXTENDED_STATUS = 2,
MAV_DATA_STREAM_RC_CHANNELS = 3,
MAV_DATA_STREAM_RAW_CONTROLLER = 4,
MAV_DATA_STREAM_POSITION = 6,
MAV_DATA_STREAM_EXTRA1 = 10,
MAV_DATA_STREAM_EXTRA2 = 11,
MAV_DATA_STREAM_EXTRA3 = 12,
}๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Available on crate feature
dialect-development only.Expand description
A data stream is not a fixed set of messages, but rather a recommendation to the autopilot software. Individual autopilots may or may not obey the recommended messages.
Variants
MAV_DATA_STREAM_ALL = 0
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Enable all data streams
MAV_DATA_STREAM_RAW_SENSORS = 1
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Enable IMU_RAW, GPS_RAW, GPS_STATUS packets.
MAV_DATA_STREAM_EXTENDED_STATUS = 2
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Enable GPS_STATUS, CONTROL_STATUS, AUX_STATUS
MAV_DATA_STREAM_RC_CHANNELS = 3
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Enable RC_CHANNELS_SCALED, RC_CHANNELS_RAW, SERVO_OUTPUT_RAW
MAV_DATA_STREAM_RAW_CONTROLLER = 4
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Enable ATTITUDE_CONTROLLER_OUTPUT, POSITION_CONTROLLER_OUTPUT, NAV_CONTROLLER_OUTPUT.
MAV_DATA_STREAM_POSITION = 6
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Enable LOCAL_POSITION, GLOBAL_POSITION_INT messages.
MAV_DATA_STREAM_EXTRA1 = 10
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Dependent on the autopilot
MAV_DATA_STREAM_EXTRA2 = 11
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Dependent on the autopilot
MAV_DATA_STREAM_EXTRA3 = 12
๐Deprecated: See
MESSAGE_INTERVAL (Superseded since 2015-06)Dependent on the autopilot
Implementations