pub struct BATTERY_STATUS_V2_DATA {
pub voltage: f32,
pub current: f32,
pub capacity_consumed: f32,
pub capacity_remaining: f32,
pub status_flags: MavBatteryStatusFlags,
pub temperature: i16,
pub id: u8,
pub percent_remaining: u8,
}dialect-development only.Expand description
Battery dynamic information. This should be streamed (nominally at 1Hz). Static/invariant battery information is sent in BATTERY_INFO. Note that smart batteries should set the MAV_BATTERY_STATUS_FLAGS_CAPACITY_RELATIVE_TO_FULL bit to indicate that supplied capacity values are relative to a battery that is known to be full. Power monitors would not set this bit, indicating that capacity_consumed is relative to drone power-on, and that other values are estimated based on the assumption that the battery was full on power-on.
ID: 369
Fields
voltage: f32Battery voltage (total). NaN: field not provided.
current: f32Battery current (through all cells/loads). Positive value when discharging and negative if charging. NaN: field not provided.
capacity_consumed: f32Consumed charge. NaN: field not provided. This is either the consumption since power-on or since the battery was full, depending on the value of MAV_BATTERY_STATUS_FLAGS_CAPACITY_RELATIVE_TO_FULL.
capacity_remaining: f32Remaining charge (until empty). NaN: field not provided. Note: If MAV_BATTERY_STATUS_FLAGS_CAPACITY_RELATIVE_TO_FULL is unset, this value is based on the assumption the battery was full when the system was powered.
status_flags: MavBatteryStatusFlagsFault, health, readiness, and other status indications.
temperature: i16Temperature of the whole battery pack (not internal electronics). INT16_MAX field not provided.
id: u8Battery ID
percent_remaining: u8Remaining battery energy. Values: [0-100], UINT8_MAX: field not provided.
Implementations