pub struct CELLULAR_STATUS_DATA {Show 18 fields
pub mcc: u16,
pub mnc: u16,
pub lac: u16,
pub status: CellularStatusFlag,
pub failure_reason: CellularNetworkFailedReason,
pub mavtype: CellularNetworkRadioType,
pub quality: u8,
pub id: u8,
pub link_tx_rate: u32,
pub link_rx_rate: u32,
pub cell_tower_id: CharArray<9>,
pub band_number: u8,
pub band_frequency: f32,
pub channel_number: u32,
pub rx_level: f32,
pub tx_level: f32,
pub rx_quality: f32,
pub sinr: f32,
}dialect-development only.Expand description
Cellular network status as reported by a particular modem. This is primarily intended for logging, but a GCS may choose to display link_tx_rate and link_rx_rate. Note that a value of 0 in the id field indicates that the sender does not support reporting of multiple modems. Message data should be from a single modem, but that is not guaranteed.
ID: 334
Fields
mcc: u16Mobile country code. If unknown, set to UINT16_MAX
mnc: u16Mobile network code. If unknown, set to UINT16_MAX
lac: u16Location area code. If unknown, set to 0
status: CellularStatusFlagCellular modem status
failure_reason: CellularNetworkFailedReasonFailure reason when status in in CELLULAR_STATUS_FLAG_FAILED
mavtype: CellularNetworkRadioTypeCellular network radio type: gsm, cdma, lte…
quality: u8Signal quality in percent. If unknown, set to UINT8_MAX
id: u8Cellular modem instance number. Indexed from 1.
link_tx_rate: u32Download rate.
link_rx_rate: u32Upload rate.
cell_tower_id: CharArray<9>ID of the currently connected cell tower. This must be NULL terminated if the length is less than 9 human-readable chars, and without the null termination (NULL) byte if the length is exactly 9 chars.
band_number: u8LTE frequency band number.
band_frequency: f32LTE radio frequency.
channel_number: u32The channel number (CN). Absolute radio-frequency (ARFCN) / E-UTRA (EARFCN) / UTRA (UARFCN) / New radio (NR_CH).
rx_level: f32On 3G is Received Signal Code Power (RSCP). On LTE is Reference Signal Received Power (RSRP). On 5G is New Radio Reference Signal Received Power (NR_RSRP).
tx_level: f32Transmitter (modem) signal absolute power level.
rx_quality: f32On 3G is Receiver Quality (RxQual). On LTE is Reference Signal Received Quality (RSRQ). On 5G is New Radio Reference Signal Received Quality (NR_RSRQ).
sinr: f32Signal to interference plus noise ratio (SINR).
Implementations