pub struct GIMBAL_MANAGER_SET_ATTITUDE_DATA {
pub flags: GimbalManagerFlags,
pub q: [f32; 4],
pub angular_velocity_x: f32,
pub angular_velocity_y: f32,
pub angular_velocity_z: f32,
pub target_system: u8,
pub target_component: u8,
pub gimbal_device_id: u8,
}dialect-development only.Expand description
High level message to control a gimbal’s attitude. This message is to be sent to the gimbal manager (e.g. from a ground station). Angles and rates can be set to NaN according to use case.
ID: 282
Fields
flags: GimbalManagerFlagsHigh level gimbal manager flags to use.
q: [f32; 4]Quaternion components, w, x, y, z (1 0 0 0 is the null-rotation, the frame is depends on whether the flag GIMBAL_MANAGER_FLAGS_YAW_LOCK is set)
angular_velocity_x: f32X component of angular velocity, positive is rolling to the right, NaN to be ignored.
angular_velocity_y: f32Y component of angular velocity, positive is pitching up, NaN to be ignored.
angular_velocity_z: f32Z component of angular velocity, positive is yawing to the right, NaN to be ignored.
target_system: u8System ID
target_component: u8Component ID
gimbal_device_id: u8Component ID of gimbal device to address (or 1-6 for non-MAVLink gimbal), 0 for all gimbal device components. Send command multiple times for more than one gimbal (but not all gimbals).
Implementations