pub struct SYS_STATUS_DATA {Show 16 fields
pub onboard_control_sensors_present: MavSysStatusSensor,
pub onboard_control_sensors_enabled: MavSysStatusSensor,
pub onboard_control_sensors_health: MavSysStatusSensor,
pub load: u16,
pub voltage_battery: u16,
pub current_battery: i16,
pub drop_rate_comm: u16,
pub errors_comm: u16,
pub errors_count1: u16,
pub errors_count2: u16,
pub errors_count3: u16,
pub errors_count4: u16,
pub battery_remaining: i8,
pub onboard_control_sensors_present_extended: MavSysStatusSensorExtended,
pub onboard_control_sensors_enabled_extended: MavSysStatusSensorExtended,
pub onboard_control_sensors_health_extended: MavSysStatusSensorExtended,
}dialect-development only.Expand description
Sensor and subsystem status information. Provides a compact representation of sensor/subsystem status and a few other basic statistics.
ID: 1
Fields
onboard_control_sensors_present: MavSysStatusSensorBitmap showing which onboard controllers and sensors are present. Value of 0: not present. Value of 1: present.
onboard_control_sensors_enabled: MavSysStatusSensorBitmap showing which onboard controllers and sensors are enabled: Value of 0: not enabled. Value of 1: enabled.
onboard_control_sensors_health: MavSysStatusSensorBitmap showing which onboard controllers and sensors have an error (or are operational). Value of 0: error. Value of 1: healthy.
load: u16Maximum usage in percent of the mainloop time. Values: [0-1000] - should always be below 1000
voltage_battery: u16Battery voltage, UINT16_MAX: Voltage not sent by autopilot
current_battery: i16Battery current, -1: Current not sent by autopilot
drop_rate_comm: u16Communication drop rate, (UART, I2C, SPI, CAN), dropped packets on all links (packets that were corrupted on reception on the MAV)
errors_comm: u16Communication errors (UART, I2C, SPI, CAN), dropped packets on all links (packets that were corrupted on reception on the MAV)
errors_count1: u16Autopilot-specific errors
errors_count2: u16Autopilot-specific errors
errors_count3: u16Autopilot-specific errors
errors_count4: u16Autopilot-specific errors
battery_remaining: i8Battery energy remaining, -1: Battery remaining energy not sent by autopilot
onboard_control_sensors_present_extended: MavSysStatusSensorExtendedBitmap showing which onboard controllers and sensors are present. Value of 0: not present. Value of 1: present.
onboard_control_sensors_enabled_extended: MavSysStatusSensorExtendedBitmap showing which onboard controllers and sensors are enabled: Value of 0: not enabled. Value of 1: enabled.
onboard_control_sensors_health_extended: MavSysStatusSensorExtendedBitmap showing which onboard controllers and sensors have an error (or are operational). Value of 0: error. Value of 1: healthy.
Implementations